# fasmga.py

fasmga.py is a [Fasm.ga](https://fasmga.org) API wrapper written using asyncio.
[Fasm.ga](https://fasmga.org) is a free and open-source URL shortener.

## Installation
fasmga.py works with Python 3.7 and greater. \
To install, you need to have pip installed first.
```bash
pip install -U fasmga.py
```
Note: The package name is `fasmga.py` and __not__ `fasmga`!

## Examples
See the examples directory.
